aboutsummaryrefslogtreecommitdiff
path: root/hid_darwin.c
diff options
context:
space:
mode:
Diffstat (limited to 'hid_darwin.c')
-rw-r--r--hid_darwin.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/hid_darwin.c b/hid_darwin.c
index 9f3f854..a8f03b2 100644
--- a/hid_darwin.c
+++ b/hid_darwin.c
@@ -542,8 +542,8 @@ t_int hid_build_device_list(t_hid *x)
if(HIDBuildDeviceList (NULL, NULL))
error("[hid]: no HID devices found\n");
- /* send the [menu( msg to set the [hid_menu] to blank */
- outlet_anything( x->x_device_name_outlet, gensym( "menu" ),0,NULL );
+ /* send the [options( msg to set the [hid_menu] to blank */
+ outlet_anything( x->x_device_name_outlet, gensym( "options" ),0,NULL );
pCurrentHIDDevice = HIDGetFirstDevice();
while ( pCurrentHIDDevice != NULL )